@@ -16,6 +16,10 @@
 #include <malloc/malloc.h>
 #endif
 
+#ifdef _OPENMP
+#include <omp.h>
+#endif
+
 #ifdef GPAW_HPM
 void HPM_Start(char *);
 void HPM_Stop(char *);
@@ -77,6 +81,18 @@ PyObject* craypat_region_end(PyObject *self, PyObject *args)
 }
 #endif
 
+PyObject* get_num_threads(PyObject *self, PyObject *args)
+{
+  int nthreads = 1;
+#ifdef _OPENMP
+  #pragma omp parallel
+  {
+    nthreads = omp_get_num_threads();
+  }
+#endif
+  return Py_BuildValue("i", nthreads);
+}
+
 #ifdef PARALLEL
 #include <mpi.h>
 
