@@ -55,7 +55,7 @@ for fname, name in zip(['cl_field.ind', 'qm_field.ind', 'tot_field.ind'],
     atoms = ind.atoms                          # Atoms
 
     do_plot(d_g, ng, box, atoms)
-    plt.title('%s\nField enhancement @ %.2f eV' % (name, freq))
+    plt.title(f'{name}\nField enhancement @ {freq:.2f} eV')
     plt.savefig(fname + '_Ffe.png', bbox_inches='tight')
 
     # Imaginary part of density
@@ -70,6 +70,5 @@ for fname, name in zip(['cl_field.ind', 'qm_field.ind', 'tot_field.ind'],
     d_g = ind.Fphi_wg[w].imag
     ng = d_g.shape
     do_plot(d_g, ng, box, atoms)
-    plt.title('%s\nImaginary part of induced potential @ %.2f eV' %
-              (name, freq))
+    plt.title(f'{name}\nImaginary part of induced potential @ {freq:.2f} eV')
     plt.savefig(fname + '_Fphi.png', bbox_inches='tight')
