@@ -15,9 +15,8 @@ mixer = Mixer(0.02, 5, 1.0)
 # Parallelzation settings
 parallel = {'sl_auto': True, 'domain': 2, 'augment_grids': True}
 
-# Increase the accuracy of PoissonSolver and
-# apply multipole corrections for monopole and dipoles
-poissonsolver = PoissonSolver(eps=1e-16, remove_moment=1 + 3)
+# Apply multipole corrections for monopole and dipoles
+poissonsolver = PoissonSolver(remove_moment=1 + 3)
 
 # Ground-state calculation
 calc = GPAW(mode='lcao', xc='GLLBSC', h=0.3, nbands=360,
@@ -27,6 +26,6 @@ calc = GPAW(mode='lcao', xc='GLLBSC', h=0.3, nbands=360,
             occupations=occupations, mixer=mixer, parallel=parallel,
             maxiter=1000,
             txt='gs.out')
-atoms.set_calculator(calc)
+atoms.calc = calc
 atoms.get_potential_energy()
 calc.write('gs.gpw', mode='all')
