@@ -5,24 +5,20 @@ from gpaw import GPAW
 # Perform standard ground state calculation (with plane wave basis)
 ag = bulk('Ag')
 calc = GPAW(mode='pw',
-            xc='GLLBSC',
+            xc='LDA',
             kpts=(10, 10, 10),
-            txt='Ag_GLLBSC.txt')
-ag.set_calculator(calc)
+            txt='Ag_LDA.txt')
+ag.calc = calc
 ag.get_potential_energy()
-calc.write('Ag_GLLBSC.gpw')
-ef = calc.get_fermi_level()
+calc.write('Ag_LDA.gpw')
 
 # Restart from ground state and fix potential:
-calc = GPAW('Ag_GLLBSC.gpw',
-            nbands=16,
-            basis='dzp',
-            fixdensity=True,
-            symmetry='off',
-            convergence={'bands': 12})
-
-calc.set(kpts={'path': 'WLGXWK', 'npoints': 100})
-calc.get_potential_energy()
+calc = GPAW('Ag_LDA.gpw').fixed_density(
+    nbands=16,
+    basis='dzp',
+    symmetry='off',
+    convergence={'bands': 12},
+    kpts={'path': 'WLGXWK', 'npoints': 100})
 
 # Plot the band structure
 band_structure = calc.band_structure()
