@@ -6,7 +6,7 @@ system = Atoms('H2', positions=[[0.0, 0.0, 0.0],
                                 [0.0, 0.0, 1.0]])
 calc = EMT()
 
-system.set_calculator(calc)
+system.calc = calc
 
 opt = QuasiNewton(system, trajectory='h2.emt.traj')
 
