@@ -21,7 +21,7 @@ bulk_calc = GPAW(mode=PW(pwcutoff),
                  occupations=FermiDirac(0.01),
                  txt='si.rpa.pbe_output.txt')
 
-bulk_crystal.set_calculator(bulk_calc)
+bulk_crystal.calc = bulk_calc
 e0_bulk_pbe = bulk_crystal.get_potential_energy()
 
 # Now we have the density, but only the occupied states;
