@@ -101,7 +101,7 @@ def get_system_config(define_macros, undef_macros,
         arch = re.findall('-xarch=(\S+)', stderr)
         os.remove('cc-test.c')
         if len(arch) > 0:
-            extra_compile_args += ['-xarch=%s' % arch[-1]]
+            extra_compile_args += [f'-xarch={arch[-1]}']
 
 
         # We need the -Bstatic before the -lsunperf and -lfsu:
@@ -196,7 +196,7 @@ def get_system_config(define_macros, undef_macros,
             libraries += ['mkl_lapack',
                           'mkl_ia32', 'guide', 'pthread', 'mkl']#, 'mkl_def']
             library_dirs += libs
-            msg +=  ['* Using MKL library: %s' % library_dirs[-1]]
+            msg +=  [f'* Using MKL library: {library_dirs[-1]}']
             #extra_link_args += ['-Wl,-rpath=' + library_dirs[-1]]
         else:
             atlas = False
@@ -301,13 +301,13 @@ def check_dependencies(sources):
     for source in sources:
         path, name = os.path.split(source)
         t = mtime(path + '/', name, mtimes)
-        o = 'build/temp.%s/%s.o' % (plat, source[:-2])  # object file
+        o = f'build/temp.{plat}/{source[:-2]}.o'  # object file
         if os.path.exists(o) and t > os.stat(o)[ST_MTIME]:
             print('removing', o)
             os.remove(o)
             remove = True
 
-    so = 'build/lib.%s/_gpaw.so' % plat
+    so = f'build/lib.{plat}/_gpaw.so'
     if os.path.exists(so) and remove:
         # Remove shared object C-extension:
         # print 'removing', so
@@ -382,9 +382,9 @@ def build_interpreter(define_macros, include_dirs, libraries, library_dirs,
     objects = ' '.join(['build/temp.%s/' % plat + x[:-1] + 'o'
                         for x in cfiles])
 
-    if not os.path.isdir('build/bin.%s/' % plat):
-        os.makedirs('build/bin.%s/' % plat)
-    exefile = 'build/bin.%s/' % plat + '/gpaw-python'
+    if not os.path.isdir(f'build/bin.{plat}/'):
+        os.makedirs(f'build/bin.{plat}/')
+    exefile = f'build/bin.{plat}/' + '/gpaw-python'
 
     # if you want static linked MPI libraries, uncomment the line below
     libraries += mpi_libraries
@@ -410,9 +410,9 @@ def build_interpreter(define_macros, include_dirs, libraries, library_dirs,
     libs += ' -Wl,-dy'
     libpl = cfgDict['LIBPL']
     if glob(libpl + '/libpython*mpi*'):
-        libs += ' -lpython%s_mpi' % cfgDict['VERSION']
+        libs += f" -lpython{cfgDict['VERSION']}_mpi"
     else:
-        libs += ' -lpython%s' % cfgDict['VERSION']
+        libs += f" -lpython{cfgDict['VERSION']}"
     # libs += ' -lpython%s ' % cfgDict['VERSION']
     # if you want dynamic linked MPI libraries, uncomment the line below
     # only really needed for TAU profiling
@@ -477,7 +477,7 @@ def build_interpreter(define_macros, include_dirs, libraries, library_dirs,
 
     # Compile the parallel sources
     for src in sources:
-        obj = 'build/temp.%s/' % plat + src[:-1] + 'o'
+        obj = f'build/temp.{plat}/' + src[:-1] + 'o'
         cmd = ('%s %s %s %s -o %s -c %s ' ) % \
               (mpicompiler,
                macros,
