@@ -5,7 +5,7 @@ scalapack = True
 libxc = '/usr/common/software/libxc/4.2.3/gnu/haswell'
 include_dirs += [libxc + '/include']
 library_dirs += [libxc + '/lib']
-extra_link_args += ['-Wl,-rpath={xc}/lib'.format(xc=libxc)]
+extra_link_args += [f'-Wl,-rpath={libxc}/lib']
 extra_compile_args += ['-O2']
 if 'xc' not in libraries:
     libraries.append('xc')
