@@ -13,4 +13,4 @@ define_macros += [('GPAW_NO_UNDERSCORE_CBLACS', '1')]
 define_macros += [('GPAW_NO_UNDERSCORE_CSCALAPACK', '1')]
 include_dirs += [xc + 'include']
 library_dirs += [xc + 'lib']
-extra_link_args += ['-Wl,-rpath={xc}/lib'.format(xc=xc)]
+extra_link_args += [f'-Wl,-rpath={xc}/lib']
