@@ -41,7 +41,7 @@ e2 = molecule.get_potential_energy()
 calc.write('H2.gpw')
 
 fd = open('atomization.txt', 'w')
-print('  hydrogen atom energy:     %5.2f eV' % e1, file=fd)
-print('  hydrogen molecule energy: %5.2f eV' % e2, file=fd)
-print('  atomization energy:       %5.2f eV' % (2 * e1 - e2), file=fd)
+print(f'  hydrogen atom energy:     {e1:5.2f} eV', file=fd)
+print(f'  hydrogen molecule energy: {e2:5.2f} eV', file=fd)
+print(f'  atomization energy:       {2 * e1 - e2:5.2f} eV', file=fd)
 fd.close()
