@@ -14,19 +14,19 @@ for k in [6, 8, 10, 12]:
                 xc='LDA',
                 basis='dzp',
                 occupations=FermiDirac(0.001),
-                txt='C_groundstate_{k}.txt'.format(k=k))
+                txt=f'C_groundstate_{k}.txt')
 
     atoms.calc = calc
     atoms.get_potential_energy()
 
     calc.diagonalize_full_hamiltonian()
-    calc.write('C_groundstate_%s.gpw' % k, mode='all')
+    calc.write(f'C_groundstate_{k}.gpw', mode='all')
 
     for i, ecut in enumerate([100, 200, 300, 400]):
-        gw = G0W0(calc='C_groundstate_%s.gpw' % k,
+        gw = G0W0(calc=f'C_groundstate_{k}.gpw',
                   bands=(3, 5),
                   ecut=ecut,
                   kpts=[0],
-                  filename='C-g0w0_k%s_ecut%s' % (k, ecut))
+                  filename=f'C-g0w0_k{k}_ecut{ecut}')
 
         result = gw.calculate()
