@@ -29,6 +29,6 @@ for i, domega0 in enumerate([0.01, 0.02, 0.03, 0.04, 0.05]):
                   ecut=20,
                   domega0=domega0,
                   omega2=omega2,
-                  filename='C_g0w0_domega0_%s_omega2_%s' % (domega0, omega2))
+                  filename=f'C_g0w0_domega0_{domega0}_omega2_{omega2}')
 
         results = gw.calculate()
