@@ -3,13 +3,13 @@ from myqueue.task import task
 
 def create_tasks():
     return [
-        task('C_ecut_k_conv_GW.py@16:15h'),
+        task('C_ecut_k_conv_GW.py@24:1d'),
         task('C_ecut_k_conv_plot_GW.py', deps='C_ecut_k_conv_GW.py'),
         task('C_ecut_extrap.py', deps='C_ecut_k_conv_GW.py'),
         task('C_frequency_conv.py@1:30m'),
         task('C_frequency_conv_plot.py', deps='C_frequency_conv.py'),
         task('C_equal_test.py',
-            deps='C_ecut_k_conv_GW.py,C_frequency_conv.py'),
+             deps='C_ecut_k_conv_GW.py,C_frequency_conv.py'),
         task('BN_GW0.py@1:1h'),
         task('BN_GW0_plot.py', deps='BN_GW0.py'),
         task('MoS2_gs_GW.py@1:2h'),
