@@ -25,7 +25,7 @@ for i in range(3):
 
         calc = GPAW(h=0.3,
                     kpts=(2, 2, 1),
-                    txt='neb{}.txt'.format(j),
+                    txt=f'neb{j}.txt',
                     communicator=ranks)
 
         image.calc = calc
