@@ -10,7 +10,7 @@ si = bulk('Si', 'diamond', a)
 fd = paropen('si-gaps.csv', 'w')
 
 for k in range(2, 9, 2):
-    name = 'Si-{0}'.format(k)
+    name = f'Si-{k}'
     si.calc = GPAW(kpts={'size': (k, k, k), 'gamma': True},
                    mode=PW(200),
                    xc='PBE',
