@@ -10,6 +10,6 @@ atoms, calc = restart(basename + '.gpw')
 nbands = calc.get_number_of_bands()
 for band in range(nbands):
     wf = calc.get_pseudo_wave_function(band=band)
-    fname = '{0}_{1}.cube'.format(basename, band)
+    fname = f'{basename}_{band}.cube'
     print('writing wf', band, 'to file', fname)
     write(fname, atoms, data=wf)
