@@ -12,8 +12,7 @@ def create_tasks():
 
 
 if __name__ == '__main__':
-    from gpaw.test import equal
     exec(open('plot.py').read())
     e_dks = float(open('dks.result').readline().split()[2])
-    equal(e_dks, 532.502, 0.001)
+    assert abs(e_dks - 532.502) < 0.001
     exec(open('h2o_xas_box2.py').read())
