@@ -37,8 +37,8 @@ with broadcast_imports:
 
 assert not np.version.version.startswith('1.6.0')
 
-__version__ = '20.10.0'
-__ase_version_required__ = '3.20.1'
+__version__ = '21.1.0'
+__ase_version_required__ = '3.21.0'
 
 __all__ = ['GPAW',
            'Mixer', 'MixerSum', 'MixerDif', 'MixerSum2',
@@ -225,7 +225,8 @@ benchmark_imports = extra_parameters.pop('benchmark_imports', False)
 # Check for typos:
 for p in extra_parameters:
     # We should get rid of most of these!
-    if p not in {'sic', 'log2ng', 'PK', 'vdw0', 'df_dry_run', 'usenewlfc'}:
+    if p not in {'sic', 'log2ng', 'PK', 'vdw0', 'df_dry_run',
+                 'c_precond', 'usenewlfc'}:
         warnings.warn('Unknown parameter: ' + p)
 
 if debug:
