@@ -72,7 +72,8 @@ def vdWradii(symbols, xc):
                 n += 1
             # linear interpolation
             ncut = (n_g[n - 1] +
-                    (n_g[n] - n_g[n - 1]) * (R - r_g[n - 1]) / (r_g[n] - r_g[n - 1]))
+                    (n_g[n] - n_g[n - 1]) * (R - r_g[n - 1]) /
+                    (r_g[n] - r_g[n - 1]))
 #            print "Z, Zrg, ncut", Z, Zrg, ncut
 
             # find own R at this density
@@ -82,7 +83,8 @@ def vdWradii(symbols, xc):
                 n += 1
             # linear interpolation
             R = (r_g[n - 1] +
-                 (r_g[n] - r_g[n - 1]) * (ncut - n_g[n - 1]) / (n_g[n] - n_g[n - 1]))
+                 (r_g[n] - r_g[n - 1]) * (ncut - n_g[n - 1]) /
+                 (n_g[n] - n_g[n - 1]))
             radius[symbol] = R * Bohr
 
         radii.append(radius[symbol])
