@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import copy
 import sys
 from math import pi
@@ -148,8 +147,8 @@ class Channel:
         self.C_nb = C_bn.T
         self.phi_ng = self.basis.expand(self.C_nb[:len(self.f_n)])
 
-    def solve2(self, vr_g, scalar_relativistic=False, Z=None):
-        rgd = self.basis.rgd
+    def solve2(self, vr_g, scalar_relativistic=False, Z=None, rgd=None):
+        rgd = rgd or self.basis.rgd
         r_g = rgd.r_g
         l = self.l
         u_g = rgd.empty()
@@ -300,7 +299,11 @@ class Channel:
         g = gmax - 2
         agp1 = 1.0
         u_g[gmax - 1] = agp1 * r_g[gmax - 1]**(l + x)
-        ag = np.exp(-(-2 * e)**0.5 * (r_g[gmax - 2] - r_g[gmax - 1]))
+        with np.errstate(over='raise'):
+            try:
+                ag = np.exp(-(-2 * e)**0.5 * (r_g[gmax - 2] - r_g[gmax - 1]))
+            except FloatingPointError:
+                ag = 2e50
 
         while True:
             u_g[g] = ag * r_g[g]**(l + x)
