@@ -4,7 +4,7 @@ from io import StringIO
 
 import numpy as np
 from ase.units import Hartree
-from ase.utils import devnull
+from gpaw.utilities import devnull
 
 from gpaw import __version__ as version
 from gpaw.utilities import divrl
