@@ -12,10 +12,10 @@ from gpaw import __version__
 commands = [
     ('run', 'gpaw.cli.run'),
     ('info', 'gpaw.cli.info'),
+    ('test', 'gpaw.cli.test'),
     ('dos', 'gpaw.cli.dos'),
     ('gpw', 'gpaw.cli.gpw'),
     ('completion', 'gpaw.cli.completion'),
-    ('test', 'gpaw.test.test'),
     ('atom', 'gpaw.atom.aeatom'),
     ('diag', 'gpaw.fulldiag'),
     # ('quick', 'gpaw.cli.quick'),
@@ -76,5 +76,6 @@ def hook(parser, args):
     return args
 
 
-def main():
-    ase_main('gpaw', 'GPAW command-line tool', __version__, commands, hook)
+def main(args=None):
+    ase_main('gpaw', 'GPAW command-line tool', __version__,
+             commands, hook, args)
