@@ -1,8 +1,7 @@
 import numpy as np
+from scipy.special import erf
 from ase.units import Bohr
 
-from gpaw.utilities import erf
-
 
 class DipoleCorrection:
     """Dipole-correcting wrapper around another PoissonSolver."""
