@@ -1,9 +1,9 @@
 from math import pi, sqrt
 import numpy as np
 from numpy import exp
+from scipy.special import erf, erfc
 
 from gpaw.poisson import FDPoissonSolver
-from gpaw.utilities import cerf, erf
 from gpaw.utilities.gauss import Gaussian
 from gpaw.fd_operators import FDOperator, laplace
 from gpaw.transformers import Transformer
@@ -24,8 +24,8 @@ class HelmholtzGaussian(Gaussian):
 
         # the gpaw-Gaussian is sqrt(4 * pi) times a 3D normalized Gaussian
         return sqrt(4 * pi) * exp(-p**2) / r / 2 * (
-            np.cos(k * r) * (cerf(rhop) + cerf(rhom)) +
-            i * np.sin(k * r) * (2 + cerf(rhop) - cerf(rhom)))
+            np.cos(k * r) * (erf(rhop) + erf(rhom)) +
+            i * np.sin(k * r) * (2 + erf(rhop) - erf(rhom)))
 
 
 class ScreenedPoissonGaussian(Gaussian):
@@ -40,9 +40,6 @@ class ScreenedPoissonGaussian(Gaussian):
         mrho = (sig2 * mu - r) / (sqrt(2) * sigma)
         prho = (sig2 * mu + r) / (sqrt(2) * sigma)
 
-        def erfc(values):
-            return 1. - erf(values)
-
         # the gpaw-Gaussian is sqrt(4 * pi) times a 3D normalized Gaussian
         return sqrt(4 * pi) * exp(sig2 * mu2 / 2.0) / (2 * r) * (
             exp(-mu * r) * erfc(mrho) - exp(mu * r) * erfc(prho))
