@@ -1,9 +1,4 @@
-from math import pi, cos, sin, sqrt, acos
-
-import numpy as np
-
 from ase.atoms import Atoms
-from ase.parallel import paropen
 
 
 def read_cc1(fileobj, index=-1):
@@ -27,4 +22,3 @@ def read_cc1(fileobj, index=-1):
         images.append(Atoms(symbols=symbols, positions=positions))
         del lines[:natoms + 1]
     return images[index]
-
