@@ -56,7 +56,7 @@ class ApmB(OmegaMatrix):
 
         # calculate omega matrix
         nij = len(kss)
-        print('RPAhyb', nij, 'transitions', file=self.txt)
+        self.log('RPAhyb', nij, 'transitions')
 
         AmB = np.zeros((nij, nij))
         ApB = self.ApB
@@ -66,7 +66,8 @@ class ApmB(OmegaMatrix):
         if yukawa:
             rsf_integrals = {}
         # setup things for IVOs
-        if self.xc.excitation is not None or self.xc.excited != 0:
+        if (hasattr(self.xc, 'excitation') and
+            (self.xc.excitation is not None or self.xc.excited != 0)):
             sin_tri_weight = 1
             if self.xc.excitation is not None:
                 ex_type = self.xc.excitation.lower()
@@ -80,7 +81,7 @@ class ApmB(OmegaMatrix):
             ivo_l = None
 
         for ij in range(nij):
-            print('RPAhyb kss[' + '%d' % ij + ']=', kss[ij], file=self.txt)
+            self.log('RPAhyb kss[' + '%d' % ij + ']=', kss[ij])
 
             timer = Timer()
             timer.start('init')
@@ -137,8 +138,8 @@ class ApmB(OmegaMatrix):
             timer.stop()
 # timer2.write()
             if ij < (nij - 1):
-                print('RPAhyb estimated time left',
-                      self.time_left(timer, t0, ij, nij), file=self.txt)
+                self.log('RPAhyb estimated time left',
+                         self.time_left(timer, t0, ij, nij))
 
         # add HF parts and apply symmetry
         if hasattr(self.xc, 'hybrid'):
@@ -146,7 +147,7 @@ class ApmB(OmegaMatrix):
         else:
             weight = 0.0
         for ij in range(nij):
-            print('HF kss[' + '%d' % ij + ']', file=self.txt)
+            self.log('HF kss[' + '%d' % ij + ']')
             timer = Timer()
             timer.start('init')
             timer.stop()
@@ -175,8 +176,8 @@ class ApmB(OmegaMatrix):
 
             timer.stop()
             if ij < (nij - 1):
-                print('HF estimated time left',
-                      self.time_left(timer, t0, ij, nij), file=self.txt)
+                self.log('HF estimated time left',
+                         self.time_left(timer, t0, ij, nij))
 
         if ivo_l is not None:
             # IVO RPA after Berman, Kaldor, Chem. Phys. 43 (3) 1979
@@ -273,10 +274,10 @@ class ApmB(OmegaMatrix):
         st += '%d' % ti + 's'
         return st
 
-    def map(self, istart=None, jend=None, energy_range=None):
+    def mapAB(self, restrict={}):
         """Map A+B, A-B matrices according to constraints."""
 
-        map, self.kss = self.get_map(istart, jend, energy_range)
+        map, self.kss = self.get_map(restrict)
         if map is None:
             ApB = self.ApB.copy()
             AmB = self.AmB.copy()
@@ -291,11 +292,10 @@ class ApmB(OmegaMatrix):
 
         return ApB, AmB
 
-    def diagonalize(self, istart=None, jend=None, energy_range=None,
-                    TDA=False):
+    def diagonalize(self, restrict={}, TDA=False):
         """Evaluate Eigenvectors and Eigenvalues"""
 
-        ApB, AmB = self.map(istart, jend, energy_range)
+        ApB, AmB = self.mapAB(restrict)
         nij = len(self.kss)
 
         if TDA:
