@@ -3,12 +3,15 @@
 import os.path
 import numpy as np
 from ase import parallel as mpi
-from ase.parallel import parprint
+
+from gpaw.lrtddft.excitation import ExcitationLogger
 
 
 class FiniteDifference:
-
-    """
+    def __init__(self, atoms, propertyfunction,
+                 save=False, name='fd', ending='',
+                 d=0.001, parallel=1, log=None, txt='-', world=mpi.world):
+        """
     atoms: Atoms object
         The atoms to work on.
     propertyfunction: function that returns a single number.
@@ -32,10 +35,6 @@ class FiniteDifference:
         displacements of different atoms individually.
     """
 
-    def __init__(self, atoms, propertyfunction,
-                 save=False, name='fd', ending='',
-                 d=0.001, parallel=0, world=None):
-
         self.atoms = atoms
         self.indices = np.asarray(range(len(atoms)))
         self.propertyfunction = propertyfunction
@@ -43,19 +42,32 @@ class FiniteDifference:
         self.name = name
         self.ending = ending
         self.d = d
-        self.value = np.empty([len(self.atoms), 3])
-
-        if world is None:
-            world = mpi.world
         self.world = world
-        if world.size < 2:
-            if parallel > 1:
-                parprint('#', (self.__class__.__name__ + ':'),
-                         'Serial calculation, keyword parallel ignored.')
-                parallel = 0
+
+        if log is not None:
+            self.log = log
+        else:
+            self.log = ExcitationLogger(world=mpi.world)
+            self.log.fd = txt
+            
+        if parallel > world.size:
+            self.log('#', (self.__class__.__name__ + ':'),
+                     'Serial calculation, keyword parallel ignored.')
+            parallel = 1
         self.parallel = parallel
-        if parallel > 1:
-            self.set_parallel()
+
+        assert world.size % parallel == 0
+
+        natoms = len(self.atoms)
+        self.cores_per_atom = world.size // parallel
+        # my workers index
+        myi = world.rank // self.cores_per_atom
+        # distribute work
+        self.myindices = []
+        for a in range(natoms):
+            if a % parallel == myi:
+                self.myindices.append(a)
+        # print(world.rank, 'myindices', self.myindices)
 
     def calculate(self, a, i, filename='fd', **kwargs):
         """Evaluate finite difference  along i'th axis on a'th atom.
@@ -68,12 +80,6 @@ class FiniteDifference:
             kwargs['atoms'] = self.atoms
 
         p0 = self.atoms.positions[a, i]
-        if self.parallel > 1:
-            par = 0
-            while (par + 1) * len(self.atoms) / self.parallel <= a:
-                par += 1
-            if self.world.rank not in self.ranks[par]:
-                return
 
         self.atoms.positions[a, i] += self.d
         eplus = self.propertyfunction(**kwargs)
@@ -89,28 +95,27 @@ class FiniteDifference:
         self.atoms.positions[a, i] = p0
 
         self.value[a, i] = (eminus - eplus) / (2 * self.d)
-        if self.parallel > 1:
-            k = a - par * len(self.atoms) // self.parallel
-            self.locvalue[k, i] = (eminus - eplus) / (2 * self.d)
-            print('# rank', self.world.rank, 'Atom', a,
-                  'direction', i, 'FD: ', self.value[a, i])
+        
+        if self.parallel > 1 and self.world.rank == 0:
+            self.log('# rank', mpi.world.rank, 'Atom', a,
+                     'direction', i, 'FD: ', self.value[a, i])
         else:
-            parprint('Atom', a, 'direction', i,
-                     '\nFD: ', self.value[a, i], '\n')
-        return((eminus - eplus) / (2 * self.d))
+            self.log('Atom', a, 'direction', i,
+                     'FD: ', self.value[a, i])
 
     def run(self, **kwargs):
         """Evaluate finite differences for all atoms
         """
-
+        self.value = np.zeros([len(self.atoms), 3])
+        
         for filename, a, i in self.displacements():
-            self.calculate(a, i, filename=filename, **kwargs)
+            if a in self.myindices:
+                self.calculate(a, i, filename=filename, **kwargs)
 
-        if self.parallel > 1:
-            gathercom = self.world.new_communicator(self.ranks[:, 0])
-            if self.world.rank in self.ranks[:, 0]:
-                gathercom.all_gather(self.locvalue, self.value)
-            self.world.broadcast(self.value, 0)
+        self.world.barrier()
+        self.value /= self.cores_per_atom
+        self.world.sum(self.value)
+        
         return self.value
 
     def displacements(self):
@@ -148,25 +153,3 @@ class FiniteDifference:
                 self.calculate(a, i, filename=filename, **kwargs)
 
         return self.value
-
-    def set_parallel(self):
-        assert self.world.size == 1 or self.world.size % self.parallel == 0
-        assert len(self.atoms) % self.parallel == 0
-
-        calc = self.atoms.calc
-        calc.write(self.name + '_eq' + self.ending)
-        self.locvalue = np.empty([len(self.atoms) // self.parallel, 3])
-        ranks = np.array(range(self.world.size), dtype=int)
-        self.ranks = ranks.reshape(
-            self.parallel, self.world.size // self.parallel)
-        self.comm = []
-        for i in range(self.parallel):
-            self.comm.append(self.world.new_communicator(self.ranks[i]))
-            if self.world.rank in self.ranks[i]:
-                calc2 = calc.__class__(
-                    restart=self.name + '_eq' + self.ending,
-                    communicator=self.comm[i], txt=None)
-                self.atoms.calc = calc2
-                calc2.calculate(atoms=self.atoms)
-
-        return
