@@ -33,7 +33,7 @@ class Kmatrix:
 
     def read_indices(self):
         # Read ALL ready_rows files
-        #self.timer.start('Init read ready rows')
+        # self.timer.start('Init read ready rows')
         # root reads and then broadcasts
         data = None
         if self.lr_comms.parent_comm.rank == 0:
@@ -72,17 +72,19 @@ class Kmatrix:
 
         self.lr_comms.parent_comm.barrier()
 
-        #self.timer.start('Read K-matrix')
+        # self.timer.start('Read K-matrix')
         # Read ALL ready_rows files but on different processors
         for (k,
              K_fn) in enumerate(glob.glob(self.basefilename + '.K_matrix.*')):
-            # read every "parent comm size"th file, starting from parent comm rank
-            if k % self.lr_comms.parent_comm.size != self.lr_comms.parent_comm.rank:
+            # read every "parent comm size"th file, starting from
+            # parent comm rank
+            if (k % self.lr_comms.parent_comm.size !=
+                self.lr_comms.parent_comm.rank):
                 continue
 
             # for each file
             for line in open(K_fn, 'r', 1024 * 1024).read().splitlines():
-                #self.timer.start('Read K-matrix: elem')
+                # self.timer.start('Read K-matrix: elem')
                 if line[0] == '#':
                     if line.startswith('# K-matrix file'):
                         self.file_format = 1
@@ -93,56 +95,49 @@ class Kmatrix:
                 p = int(elems[1])
                 j = int(elems[2])
                 q = int(elems[3])
-                #self.timer.stop('Read K-matrix: elem')
+                # self.timer.stop('Read K-matrix: elem')
 
-                #self.timer.start('Read K-matrix: index')
+                # self.timer.start('Read K-matrix: index')
                 ip = self.lr_comms.index_map.get((i, p))
                 jq = self.lr_comms.index_map.get((j, q))
-                #self.timer.stop('Read K-matrix: index')
+                # self.timer.stop('Read K-matrix: index')
                 if ip is None or jq is None:
                     continue
 
                 # where to send
-                #self.timer.start('Read K-matrix: line')
+                # self.timer.start('Read K-matrix: line')
                 (proc, ehproc, ddproc, lip,
                  ljq) = self.lr_comms.get_matrix_elem_proc_and_index(ip, jq)
                 elem_lists[proc].append(line + '\n')
-                #self.timer.stop('Read K-matrix: line')
+                # self.timer.stop('Read K-matrix: line')
 
                 if ip == jq:
                     continue
 
                 # where to send transposed
-                #self.timer.start('Read K-matrix: line')
+                # self.timer.start('Read K-matrix: line')
                 (proc, ehproc, ddproc, lip,
                  ljq) = self.lr_comms.get_matrix_elem_proc_and_index(jq, ip)
                 elem_lists[proc].append(line + '\n')
-                #self.timer.stop('Read K-matrix: line')
+                # self.timer.stop('Read K-matrix: line')
 
-        #if self.parent_comm.rank == 0:
-        #    print '-------------- READING K-MATRIX done --------------------', resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
-        #    print 'elem_list sizes:',
-        #    for proc in range(self.parent_comm.size):
-        #        print len(elem_lists[proc]),
-        #    print
-
-        #self.timer.start('Read K-matrix: join')
+        # self.timer.start('Read K-matrix: join')
         for proc in range(self.lr_comms.parent_comm.size):
             elem_lists[proc] = ''.join(elem_lists[proc])
-        #self.timer.stop('Read K-matrix: join')
+        # self.timer.stop('Read K-matrix: join')
 
-        #print self.parent_comm.rank, '- elem_lists -'
-        #for (key,val) in elem_lists.items():
+        # print self.parent_comm.rank, '- elem_lists -'
+        # for (key,val) in elem_lists.items():
         #    print key, ':', val[0:120]
-        #sys.stdout.flush()
+        # sys.stdout.flush()
 
         self.lr_comms.parent_comm.barrier()
-        #self.timer.stop('Read K-matrix')
+        # self.timer.stop('Read K-matrix')
 
         self.file_format = self.lr_comms.parent_comm.max(self.file_format)
 
         # send and receive elem_list
-        #self.timer.start('Communicate K-matrix')
+        # self.timer.start('Communicate K-matrix')
         alltoall_dict = gpaw.mpi.alltoallv_string(elem_lists,
                                                   self.lr_comms.parent_comm)
         # ready for garbage collection
@@ -151,12 +146,8 @@ class Kmatrix:
         # ready for garbage collection
         del alltoall_dict
 
-        #if self.parent_comm.rank == 0:
-        #    print '-------------- communicating K-MATRIX done --------------------', resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
-        #    print 'local elem list size: ', len(local_elem_list)
-
-        #local_elem_list = ''
-        #for sending_proc in range(self.parent_comm.size):
+        # local_elem_list = ''
+        # for sending_proc in range(self.parent_comm.size):
         #    for receiving_proc in range(self.parent_comm.size):
         #        if ( sending_proc == receiving_proc and
         #             sending_proc == self.parent_comm.rank ):
@@ -171,14 +162,6 @@ class Kmatrix:
         #            local_elem_list += elist
         #
 
-        #print self.parent_comm.rank, '- local_elem_list -', local_elem_list[0:120].replace('\n', ' | ')
-        #sys.stdout.flush()
-        #sys.exit(0)
-
-        #self.timer.stop('Communicate K-matrix')
-
-        #self.timer.start('Build matrix')
-
         # Matrix build
         K_matrix = np.zeros((nlrow, nlcol))
         K_matrix[:, :] = np.NAN  # fill with NaNs to detect problems
@@ -230,20 +213,6 @@ class Kmatrix:
         # ready for garbage collection
         del local_elem_list
 
-        #self.timer.stop('Build matrix')
-
-        #if self.parent_comm.rank == 0:
-        #    print '-------------- building K-MATRIX done --------------------', resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
-
-        #print K_matrix
-
-        #for ((i,p), ip) in self.index_map.items():
-        #    for ((j,q), jq) in self.index_map.items():
-        #        lip = self.get_local_eh_index(ip)
-        #        ljq = self.get_local_dd_index(jq)
-        #        if ( lip is not None and ljq is not None ):
-        #            print 'proc #', self.parent_comm.rank, ' dd #', self.dd_comm.rank, ' eh #', self.eh_comm.rank, ': ',ip,'(', i, ',', p,') ',jq,'(', j, ',', q,')  = ', K_matrix[lip,ljq]
-
         # If any NaNs found, we did not read all matrix elements... BAD
         if np.isnan(np.sum(np.sum(K_matrix))):
             raise RuntimeError(
@@ -278,8 +247,8 @@ class Kmatrix:
         if self.K_matrix_ready:
             return
 
-        #self.timer.start('Calculate K matrix')
-        #self.timer.start('Initialize')
+        # self.timer.start('Calculate K matrix')
+        # self.timer.start('Initialize')
 
         # Filenames
         #######################################################################
@@ -316,7 +285,7 @@ class Kmatrix:
         dVxct_gip = self.calc.density.finegd.zeros(
             self.calc.density.nt_sg.shape[0])
 
-        #self.timer.stop('Initialize')
+        # self.timer.stop('Initialize')
         # Init ETA
         self.matrix_eta = QuadraticETA()
 
@@ -343,19 +312,19 @@ class Kmatrix:
                 self.log_file.flush()
 
             # Pair density
-            #self.timer.start('Pair density')
+            # self.timer.start('Pair density')
             dnt_Gip[:] = 0.0
             dnt_gip[:] = 0.0
             drhot_gip[:] = 0.0
             kss_ip.calculate_pair_density(dnt_Gip, dnt_gip, drhot_gip)
-            #self.timer.stop('Pair density')
+            # self.timer.stop('Pair density')
 
             # Smooth Hartree "pair" potential
             # for compensated pair density drhot_gip
-            #self.timer.start('Poisson')
+            # self.timer.start('Poisson')
             dVht_gip[:] = 0.0
             self.poisson.solve(dVht_gip, drhot_gip, charge=None)
-            #self.timer.stop('Poisson')
+            # self.timer.stop('Poisson')
 
             # smooth XC "pair" potential
             self.calculate_smooth_xc_pair_potential(kss_ip, dnt_gip, dVxct_gip)
@@ -376,15 +345,15 @@ class Kmatrix:
                     continue
 
                 # Pair density dn_jq
-                #self.timer.start('Pair density')
+                # self.timer.start('Pair density')
                 dnt_Gjq[:] = 0.0
                 dnt_gjq[:] = 0.0
                 drhot_gjq[:] = 0.0
                 kss_jq.calculate_pair_density(dnt_Gjq, dnt_gjq, drhot_gjq)
-                #self.timer.stop('Pair density')
+                # self.timer.stop('Pair density')
 
                 # integrate to get the final matrix element value
-                #self.timer.start('Integrate')
+                # self.timer.start('Integrate')
 
                 # init grid part
                 Ig = 0.0
@@ -395,13 +364,13 @@ class Kmatrix:
                 # XC smooth part
                 Ig += self.fxc_pre * self.calc.density.finegd.integrate(
                     dVxct_gip, dnt_gjq)
-                #self.timer.stop('Integrate')
+                # self.timer.stop('Integrate')
 
                 # Atomic corrections
-                #self.timer.start('Atomic corrections')
+                # self.timer.start('Atomic corrections')
                 Ia = self.calculate_paw_fHXC_corrections(kss_ip, kss_jq, I_asp)
 
-                #self.timer.stop('Atomic corrections')
+                # self.timer.stop('Atomic corrections')
                 Ia = self.lr_comms.dd_comm.sum(Ia)
 
                 # Total integral
@@ -413,7 +382,7 @@ class Kmatrix:
             # Write  i p j q Kipjq
             # (format: -2345.789012345678)
 
-            #self.timer.start('Write K')
+            # self.timer.start('Write K')
             # Write only on dd_comm root
             if self.lr_comms.dd_comm.rank == 0:
 
@@ -428,7 +397,7 @@ class Kmatrix:
                                       (kss_ip.occ_ind, kss_ip.unocc_ind))
                 self.ready_file.flush()
 
-            #self.timer.stop('Write K')
+            # self.timer.stop('Write K')
 
             # Update ready rows before continuing
             self.ready_indices.append([kss_ip.occ_ind, kss_ip.unocc_ind])
@@ -439,7 +408,7 @@ class Kmatrix:
             self.ready_file.close()
             self.log_file.close()
 
-        #self.timer.stop('Calculate K matrix')
+        # self.timer.stop('Calculate K matrix')
 
     def calculate_smooth_xc_pair_potential(self, kss_ip, dnt_gip, dVxct_gip):
         # Smooth xc potential
@@ -451,7 +420,7 @@ class Kmatrix:
 
         s = kss_ip.spin_ind
 
-        #self.timer.start('Smooth XC')
+        # self.timer.start('Smooth XC')
         # finite difference plus,  vxc+ = vxc(n + deriv_scale * dn)
         self.nt_g[s][:] = self.deriv_scale * dnt_gip
         self.nt_g[s][:] += self.calc.density.nt_sg[s]
@@ -467,7 +436,7 @@ class Kmatrix:
         # finite difference approx for fxc
         # vxc = (vxc+ - vxc-) / 2h
         dVxct_gip *= 1. / (2. * self.deriv_scale)
-        #self.timer.stop('Smooth XC')
+        # self.timer.stop('Smooth XC')
 
     def calculate_paw_xc_pair_potentials(self, kss_ip):
         # XC corrections
@@ -478,7 +447,7 @@ class Kmatrix:
         # s = kss_ip.spin_ind
 
         # FIXME, only spin unpolarized works
-        #self.timer.start('Atomic XC')
+        # self.timer.start('Atomic XC')
         for a, P_ni in self.calc.wfs.kpt_u[kss_ip.kpt_ind].P_ani.items():
             I_sp = np.zeros_like(self.calc.density.D_asp[a])
             I_sp_2 = np.zeros_like(self.calc.density.D_asp[a])
@@ -502,7 +471,7 @@ class Kmatrix:
             # finite difference
             I_asp[a] = (I_sp - I_sp_2) / (2. * self.deriv_scale)
 
-        #self.timer.stop('Atomic XC')
+        # self.timer.stop('Atomic XC')
 
         return I_asp
 
