@@ -1,9 +1,25 @@
 from ase.units import kB, Hartree, Bohr
 from gpaw.solvation.gridmem import NeedsGD
 from gpaw.fd_operators import Gradient
+from gpaw.io.logger import indent
 import numpy as np
 
 
+BAD_RADIUS_MESSAGE = "All atomic radii have to be finite and >= zero."
+
+
+def set_log_and_check_radii(obj, atoms, log):
+    radii = np.array(obj.atomic_radii(atoms), dtype=float)
+    obj.atomic_radii_output = radii
+    obj.symbols = atoms.get_chemical_symbols()
+    log('  Atomic radii for %s:' % (obj.__class__, ))
+    for a, (s, r) in enumerate(
+            zip(obj.symbols, radii)):
+        log('    %3d %-2s %10.5f' % (a, s, r))
+    if not np.isfinite(radii).all() or (radii < 0).any():
+        raise ValueError(BAD_RADIUS_MESSAGE)
+
+
 def get_pbc_positions(atoms, r_max):
     """Return dict mapping atom index to positions in Bohr.
 
@@ -31,17 +47,6 @@ def get_pbc_positions(atoms, r_max):
     return pos_aav
 
 
-def divide_silently(x, y):
-    """Divide numpy arrays x / y ignoring all floating point errors.
-
-    Use with caution!
-    """
-    old_err = np.seterr(all='ignore')
-    result = x / y
-    np.seterr(**old_err)
-    return result
-
-
 class Cavity(NeedsGD):
     """Base class for representing a cavity in the solvent.
 
@@ -50,6 +55,7 @@ class Cavity(NeedsGD):
                      solute location to one in the bulk solvent.
     del_g_del_n_g -- The partial derivative of the cavity with respect to
                      the electron density on the fine grid.
+    grad_g_vg     -- The gradient of the cavity on the fine grid.
     V             -- global Volume in Bohr ** 3 or None
     A             -- global Area in Bohr ** 2 or None
     """
@@ -64,6 +70,7 @@ class Cavity(NeedsGD):
         NeedsGD.__init__(self)
         self.g_g = None
         self.del_g_del_n_g = None
+        self.grad_g_vg = None
         self.surface_calculator = surface_calculator
         self.volume_calculator = volume_calculator
         self.V = None  # global Volume
@@ -72,6 +79,9 @@ class Cavity(NeedsGD):
     def estimate_memory(self, mem):
         ngrids = 1 + self.depends_on_el_density
         mem.subnode('Distribution Function', ngrids * self.gd.bytecount())
+        mem.subnode(
+            'Gradient of Distribution Function', 3 * self.gd.bytecount()
+        )
         if self.surface_calculator is not None:
             self.surface_calculator.estimate_memory(
                 mem.subnode('Surface Calculator')
@@ -82,7 +92,7 @@ class Cavity(NeedsGD):
             )
 
     def update(self, atoms, density):
-        """Update the cavity.
+        """Update the cavity and its gradient.
 
         atoms are None, iff they have not changed.
 
@@ -117,6 +127,7 @@ class Cavity(NeedsGD):
     def allocate(self):
         NeedsGD.allocate(self)
         self.g_g = self.gd.empty()
+        self.grad_g_vg = self.gd.empty(3)
         if self.depends_on_el_density:
             self.del_g_del_n_g = self.gd.empty()
         if self.surface_calculator is not None:
@@ -145,17 +156,28 @@ class Cavity(NeedsGD):
         """Return whether the cavity depends explicitly on atomic positions."""
         raise NotImplementedError()
 
-    def print_parameters(self, text):
-        """Print parameters using text function."""
-        typ = self.surface_calculator and self.surface_calculator.__class__
-        text('surface calculator: %s' % (typ, ))
-        if self.surface_calculator is not None:
-            self.surface_calculator.print_parameters(text)
-        text()
-        typ = self.volume_calculator and self.volume_calculator.__class__
-        text('volume calculator: %s' % (typ, ))
-        if self.volume_calculator is not None:
-            self.volume_calculator.print_parameters(text)
+    def __str__(self):
+        s = 'Cavity: %s\n' % (self.__class__, )
+        for calc, calcname in ((self.surface_calculator, 'Surface'),
+                               (self.volume_calculator, 'Volume')):
+            if calc is None:
+                s += '  %s Calculator: None\n' % (calcname, )
+            else:
+                s += indent(str(calc))
+        return s
+
+    def update_atoms(self, atoms, log):
+        """Inexpensive initialization when atoms change."""
+        pass
+
+    def summary(self, log):
+        """Log cavity surface area and volume."""
+        A = (self.A * Bohr ** 2 if self.A is not None
+             else 'not calculated (no calculator defined)')
+        V = (self.V * Bohr ** 3 if self.V is not None
+             else 'not calculated (no calculator defined)')
+        log('Cavity Surface Area: %s' % (A, ))
+        log('Cavity Volume: %s' % (V, ))
 
 
 class EffectivePotentialCavity(Cavity):
@@ -206,13 +228,24 @@ class EffectivePotentialCavity(Cavity):
             self.del_g_del_n_g.fill(self.minus_beta)
             self.del_g_del_n_g *= self.g_g
             self.del_g_del_n_g *= self.effective_potential.del_u_del_n_g
+        # This class supports the GradientSurface API,
+        # so we can use it for the gradient also
+        grad_inner_vg = self.get_grad_inner()
+        del_outer_del_inner = self.get_del_outer_del_inner()
+        for i in (0, 1, 2):
+            np.multiply(
+                grad_inner_vg[i],
+                del_outer_del_inner,
+                self.grad_g_vg[i]
+            )
         return True
 
     def get_del_r_vg(self, atom_index, density):
         u = self.effective_potential
         del_u_del_r_vg = u.get_del_r_vg(atom_index, density)
+        # there should be no more NaNs now, but let's keep the hint
         # asserts lim_(||r - r_atom|| -> 0) dg/du * du/dr_atom = 0
-        del_u_del_r_vg[np.isnan(del_u_del_r_vg)] = .0
+        # del_u_del_r_vg[np.isnan(del_u_del_r_vg)] = .0
         return self.minus_beta * self.g_g * del_u_del_r_vg
 
     @property
@@ -223,27 +256,19 @@ class EffectivePotentialCavity(Cavity):
     def depends_on_atomic_positions(self):
         return self.effective_potential.depends_on_atomic_positions
 
-    def print_parameters(self, text):
-        text('effective potential: %s' % (self.effective_potential.__class__))
-        self.effective_potential.print_parameters(text)
-        text()
-        Cavity.print_parameters(self, text)
+    def __str__(self):
+        s = Cavity.__str__(self)
+        s += indent(str(self.effective_potential))
+        s += '  temperature: %s\n' % (self.temperature, )
+        return s
+
+    def update_atoms(self, atoms, log):
+        self.effective_potential.update_atoms(atoms, log)
 
     # --- BEGIN GradientSurface API ---
-    def get_inner_function(self):
-        return np.minimum(self.effective_potential.u_g, 1e20)
-
-    def get_inner_function_boundary_value(self):
-        if hasattr(self.effective_potential, 'grad_u_vg'):
-            raise NotImplementedError
-        else:
-            return .0
 
     def get_grad_inner(self):
-        if hasattr(self.effective_potential, 'grad_u_vg'):
-            return self.effective_potential.grad_u_vg
-        else:
-            raise NotImplementedError
+        return self.effective_potential.grad_u_vg
 
     def get_del_outer_del_inner(self):
         return self.minus_beta * self.g_g
@@ -256,6 +281,7 @@ class Potential(NeedsGD):
 
     Attributes:
     u_g           -- The potential on the fine grid in Hartree.
+    grad_u_vg     -- The gradient of the potential of the fine grid.
     del_u_del_n_g -- Partial derivative with respect to the electron density.
     """
 
@@ -263,6 +289,7 @@ class Potential(NeedsGD):
         NeedsGD.__init__(self)
         self.u_g = None
         self.del_u_del_n_g = None
+        self.grad_u_vg = None
 
     @property
     def depends_on_el_density(self):
@@ -277,15 +304,17 @@ class Potential(NeedsGD):
     def estimate_memory(self, mem):
         ngrids = 1 + self.depends_on_el_density
         mem.subnode('Potential', ngrids * self.gd.bytecount())
+        mem.subnode('Gradient of Potential', 3 * self.gd.bytecount())
 
     def allocate(self):
         NeedsGD.allocate(self)
         self.u_g = self.gd.empty()
         if self.depends_on_el_density:
             self.del_u_del_n_g = self.gd.empty()
+        self.grad_u_vg = self.gd.empty(3)
 
     def update(self, atoms, density):
-        """Update the potential.
+        """Update the potential and its gradient.
 
         atoms are None, iff they have not changed.
 
@@ -297,7 +326,11 @@ class Potential(NeedsGD):
         """Return spatial derivatives with respect to atomic position."""
         raise NotImplementedError()
 
-    def print_parameters(self, text):
+    def __str__(self):
+        return 'Potential: %s\n' % (self.__class__, )
+
+    def update_atoms(self, atoms, log):
+        """Inexpensive initialization when atoms change."""
         pass
 
 
@@ -313,7 +346,7 @@ class Power12Potential(Potential):
     depends_on_el_density = False
     depends_on_atomic_positions = True
 
-    def __init__(self, atomic_radii, u0, pbc_cutoff=1e-6):
+    def __init__(self, atomic_radii, u0, pbc_cutoff=1e-6, tiny=1e-10):
         """Constructor for the Power12Potential class.
 
         Arguments:
@@ -327,32 +360,28 @@ class Power12Potential(Potential):
         self.atomic_radii = atomic_radii
         self.u0 = float(u0)
         self.pbc_cutoff = float(pbc_cutoff)
+        self.tiny = float(tiny)
         self.r12_a = None
         self.r_vg = None
         self.pos_aav = None
         self.del_u_del_r_vg = None
         self.atomic_radii_output = None
         self.symbols = None
-        self.grad_u_vg = None
 
     def estimate_memory(self, mem):
         Potential.estimate_memory(self, mem)
         nbytes = self.gd.bytecount()
         mem.subnode('Coordinates', 3 * nbytes)
         mem.subnode('Atomic Position Derivative', 3 * nbytes)
-        mem.subnode('Gradient', 3 * nbytes)
 
     def allocate(self):
         Potential.allocate(self)
         self.r_vg = self.gd.get_grid_point_coordinates()
         self.del_u_del_r_vg = self.gd.empty(3)
-        self.grad_u_vg = self.gd.empty(3)
 
     def update(self, atoms, density):
         if atoms is None:
             return False
-        self.atomic_radii_output = np.array(self.atomic_radii(atoms))
-        self.symbols = atoms.get_chemical_symbols()
         self.r12_a = (self.atomic_radii_output / Bohr) ** 12
         r_cutoff = (self.r12_a.max() * self.u0 / self.pbc_cutoff) ** (1. / 12.)
         self.pos_aav = get_pbc_positions(atoms, r_cutoff)
@@ -365,18 +394,14 @@ class Power12Potential(Potential):
                 origin_vg = pos_v[:, na, na, na]
                 r_diff_vg = self.r_vg - origin_vg
                 r_diff2_g = (r_diff_vg ** 2).sum(0)
-                r12_g = r_diff2_g ** 6
-                r14_g = r12_g * r_diff2_g
-                self.u_g += divide_silently(r12, r12_g)
-                self.grad_u_vg += divide_silently(r12 * r_diff_vg, r14_g)
+                r_diff2_g[r_diff2_g < self.tiny] = self.tiny
+                u_g = r12 / r_diff2_g ** 6
+                self.u_g += u_g
+                u_g /= r_diff2_g
+                r_diff_vg *= u_g[na, ...]
+                self.grad_u_vg += r_diff_vg
         self.u_g *= self.u0 / Hartree
-        # np.exp(-np.inf) = .0
-        self.u_g[np.isnan(self.u_g)] = np.inf
-
         self.grad_u_vg *= -12. * self.u0 / Hartree
-        # mask points where the limit of all later
-        # calculations is zero anyways
-        self.grad_u_vg[...] = np.nan_to_num(self.grad_u_vg)
         # avoid overflow in norm calculation:
         self.grad_u_vg[self.grad_u_vg < -1e20] = -1e20
         self.grad_u_vg[self.grad_u_vg > 1e20] = 1e20
@@ -390,23 +415,24 @@ class Power12Potential(Potential):
         for pos_v in self.pos_aav[atom_index]:
             origin_vg = pos_v[:, na, na, na]
             diff_vg = self.r_vg - origin_vg
-            r14_g = np.sum(diff_vg ** 2, axis=0) ** 7
-            self.del_u_del_r_vg += divide_silently(diff_vg, r14_g)
+            diff2_g = (diff_vg ** 2).sum(0)
+            diff2_g[diff2_g < self.tiny] = self.tiny
+            diff2_g **= 7
+            diff_vg /= diff2_g[na, ...]
+            self.del_u_del_r_vg += diff_vg
         self.del_u_del_r_vg *= (12. * u0 * r12)
         return self.del_u_del_r_vg
 
-    def print_parameters(self, text):
-        if self.symbols is None:
-            text('atomic_radii: not initialized (dry run)')
-        else:
-            text('atomic_radii:')
-            for a, (s, r) in enumerate(
-                zip(self.symbols, self.atomic_radii_output)
-            ):
-                text('%3d %-2s %10.5f' % (a, s, r))
-        text('u0: %s' % (self.u0, ))
-        text('pbc_cutoff: %s' % (self.pbc_cutoff, ))
-        Potential.print_parameters(self, text)
+    def __str__(self):
+        s = Potential.__str__(self)
+        s += '  atomic_radii: %s\n' % (self.atomic_radii, )
+        s += '  u0: %s\n' % (self.u0, )
+        s += '  pbc_cutoff: %s\n' % (self.pbc_cutoff, )
+        s += '  tiny: %s\n' % (self.tiny, )
+        return s
+
+    def update_atoms(self, atoms, log):
+        set_log_and_check_radii(self, atoms, log)
 
 
 class SmoothStepCavity(Cavity):
@@ -419,7 +445,7 @@ class SmoothStepCavity(Cavity):
     def __init__(
         self,
         density,
-        surface_calculator=None, volume_calculator=None
+        surface_calculator=None, volume_calculator=None,
     ):
         """Constructor for the SmoothStepCavity class.
 
@@ -462,6 +488,15 @@ class SmoothStepCavity(Cavity):
                 self.density.del_rho_del_n_g,
                 self.del_g_del_n_g
             )
+        # This class supports the GradientSurface API,
+        # so we can use it for the gradient also
+        grad_inner_vg = self.get_grad_inner()
+        del_outer_del_inner = self.get_del_outer_del_inner()
+        for i in (0, 1, 2):
+            np.multiply(
+                grad_inner_vg[i],
+                del_outer_del_inner,
+                self.grad_g_vg[i])
         return True
 
     def update_smooth_step(self, rho_g):
@@ -473,21 +508,17 @@ class SmoothStepCavity(Cavity):
             atom_index, density
         )
 
-    def print_parameters(self, text):
-        text('density: %s' % (self.density.__class__))
-        self.density.print_parameters(text)
-        text()
-        Cavity.print_parameters(self, text)
+    def __str__(self):
+        s = Cavity.__str__(self)
+        s += indent(str(self.density))
+        return s
+
+    def update_atoms(self, atoms, log):
+        self.density.update_atoms(atoms, log)
 
     # --- BEGIN GradientSurface API ---
-    def get_inner_function(self):
-        return self.density.rho_g
-
-    def get_inner_function_boundary_value(self):
-        return .0
-
     def get_grad_inner(self):
-        raise NotImplementedError
+        return self.density.grad_rho_vg
 
     def get_del_outer_del_inner(self):
         return self.del_g_del_rho_g
@@ -501,24 +532,28 @@ class Density(NeedsGD):
     Attributes:
     rho_g           -- The density on the fine grid in 1 / Bohr ** 3.
     del_rho_del_n_g -- Partial derivative with respect to the electron density.
+    grad_rho_vg     -- The gradient of the density on the fine grid.
     """
 
     def __init__(self):
         NeedsGD.__init__(self)
         self.rho_g = None
         self.del_rho_del_n_g = None
+        self.grad_rho_vg = None
 
     def estimate_memory(self, mem):
         nbytes = self.gd.bytecount()
         mem.subnode('Density', nbytes)
         if self.depends_on_el_density:
             mem.subnode('Density Derivative', nbytes)
+        mem.subnode('Gradient of Density', 3 * nbytes)
 
     def allocate(self):
         NeedsGD.allocate(self)
         self.rho_g = self.gd.empty()
         if self.depends_on_el_density:
             self.del_rho_del_n_g = self.gd.empty()
+        self.grad_rho_vg = self.gd.empty(3)
 
     def update(self, atoms, density):
         raise NotImplementedError()
@@ -531,11 +566,52 @@ class Density(NeedsGD):
     def depends_on_atomic_positions(self):
         raise NotImplementedError()
 
-    def print_parameters(self, text):
+    def __str__(self):
+        return "Density: %s\n" % (self.__class__, )
+
+    def update_atoms(self, atoms, log):
+        """Inexpensive initialization when atoms change."""
         pass
 
 
-class ElDensity(Density):
+class FDGradientDensity(Density):
+    """Base class for all Density classes with finite difference gradient"""
+
+    def __init__(self, boundary_value, nn=3):
+        """Constructur for the FDGradientDensity class.
+
+        Arguments:
+        boundary_value -- Boundary value of rho_g
+                          (for non-periodic directions).
+        nn             -- Stencil size for the finite difference gradient.
+        """
+        Density.__init__(self)
+        self.boundary_value = boundary_value
+        self.nn = nn
+        self.gradient = None
+
+    def allocate(self):
+        Density.allocate(self)
+        self.gradient = [
+            Gradient(self.gd, i, 1.0, self.nn) for i in (0, 1, 2)
+        ]
+
+    def update(self, atoms, density):
+        changed = self.update_only_density(atoms, density)
+        if changed:
+            self.update_gradient()
+        return changed
+
+    def update_gradient(self):
+        if self.boundary_value != 0:
+            in_g = self.rho_g - self.boundary_value
+        else:
+            in_g = self.rho_g
+        for i in (0, 1, 2):
+            self.gradient[i].apply(in_g, self.grad_rho_vg[i])
+
+
+class ElDensity(FDGradientDensity):
     """Wrapper class for using the electron density in a SmoothStepCavity.
 
     (Hopefully small) negative values of the electron density are set to zero.
@@ -544,17 +620,26 @@ class ElDensity(Density):
     depends_on_el_density = True
     depends_on_atomic_positions = False
 
+    def __init__(self, nn=3):
+        """Constructor for the ElDensity class.
+
+        Arguments:
+        nn -- Stencil size for the finite difference gradient.
+        """
+        FDGradientDensity.__init__(self, boundary_value=.0, nn=nn)
+
     def allocate(self):
-        Density.allocate(self)
+        FDGradientDensity.allocate(self)
         self.del_rho_del_n_g = 1.  # free array
 
-    def update(self, atoms, density):
+    def update_only_density(self, atoms, density):
         self.rho_g[:] = density.nt_g
         self.rho_g[self.rho_g < .0] = .0
         return True
 
 
-class SSS09Density(Density):
+# TODO: implement analytic gradient for SSS09Density
+class SSS09Density(FDGradientDensity):
     """Fake density from atomic radii for the use in a SmoothStepCavity.
 
     Following V. M. Sanchez, M. Sued and D. A. Scherlis,
@@ -564,7 +649,7 @@ class SSS09Density(Density):
     depends_on_el_density = False
     depends_on_atomic_positions = True
 
-    def __init__(self, atomic_radii, pbc_cutoff=1e-3):
+    def __init__(self, atomic_radii, pbc_cutoff=1e-3, nn=3, tiny=1e-100):
         """Constructor for the SSS09Density class.
 
         Arguments:
@@ -572,32 +657,32 @@ class SSS09Density(Density):
                         to an iterable of atomic radii in Angstroms.
         pbc_cutoff   -- Cutoff in eV for including neighbor cells in
                         a calculation with periodic boundary conditions.
+        nn           -- Stencil size for the finite difference gradient.
         """
-        Density.__init__(self)
+        FDGradientDensity.__init__(self, boundary_value=.0, nn=nn)
         self.atomic_radii = atomic_radii
         self.atomic_radii_output = None
         self.symbols = None
         self.pbc_cutoff = float(pbc_cutoff)
+        self.tiny = float(tiny)
         self.pos_aav = None
         self.r_vg = None
         self.del_rho_del_r_vg = None
 
     def estimate_memory(self, mem):
-        Density.estimate_memory(self, mem)
+        FDGradientDensity.estimate_memory(self, mem)
         nbytes = self.gd.bytecount()
         mem.subnode('Coordinates', 3 * nbytes)
         mem.subnode('Atomic Position Derivative', 3 * nbytes)
 
     def allocate(self):
-        Density.allocate(self)
+        FDGradientDensity.allocate(self)
         self.r_vg = self.gd.get_grid_point_coordinates()
         self.del_rho_del_r_vg = self.gd.empty(3)
 
-    def update(self, atoms, density):
+    def update_only_density(self, atoms, density):
         if atoms is None:
             return False
-        self.atomic_radii_output = np.array(self.atomic_radii(atoms))
-        self.symbols = atoms.get_chemical_symbols()
         r_a = self.atomic_radii_output / Bohr
         r_cutoff = r_a.max() - np.log(self.pbc_cutoff)
         self.pos_aav = get_pbc_positions(atoms, r_cutoff)
@@ -619,23 +704,22 @@ class SSS09Density(Density):
             origin_vg = pos_v[:, na, na, na]
             r_diff_vg = self.r_vg - origin_vg
             norm_r_diff_g = np.sum(r_diff_vg ** 2, axis=0) ** .5
+            norm_r_diff_g[norm_r_diff_g < self.tiny] = self.tiny
             exponential = np.exp(r_a - norm_r_diff_g)
-            self.del_rho_del_r_vg += divide_silently(
-                exponential * r_diff_vg, norm_r_diff_g
-            )
+            exponential /= norm_r_diff_g
+            r_diff_vg *= exponential[na, ...]
+            self.del_rho_del_r_vg += r_diff_vg
         return self.del_rho_del_r_vg
 
-    def print_parameters(self, text):
-        if self.symbols is None:
-            text('atomic_radii: not initialized (dry run)')
-        else:
-            text('atomic_radii:')
-            for a, (s, r) in enumerate(
-                zip(self.symbols, self.atomic_radii_output)
-            ):
-                text('%3d %-2s %10.5f' % (a, s, r))
-        text('pbc_cutoff: %s' % (self.pbc_cutoff, ))
-        Density.print_parameters(self, text)
+    def __str__(self):
+        s = FDGradientDensity.__str__(self)
+        s += '  atomic_radii: %s\n' % (self.atomic_radii, )
+        s += '  pbc_cutoff: %s\n' % (self.pbc_cutoff, )
+        s += '  tiny: %s\n' % (self.tiny, )
+        return s
+
+    def update_atoms(self, atoms, log):
+        set_log_and_check_radii(self, atoms, log)
 
 
 class ADM12SmoothStepCavity(SmoothStepCavity):
@@ -698,11 +782,12 @@ class ADM12SmoothStepCavity(SmoothStepCavity):
         dt = -2. * np.sin(arg / 2.) ** 2 / (lnmax - lnmin)
         return (t, dt)
 
-    def print_parameters(self, text):
-        text('rhomin: %s' % (self.rhomin, ))
-        text('rhomax: %s' % (self.rhomax, ))
-        text('epsinf: %s' % (self.epsinf, ))
-        SmoothStepCavity.print_parameters(self, text)
+    def __str__(self):
+        s = SmoothStepCavity.__str__(self)
+        s += '  rhomin: %s\n' % (self.rhomin, )
+        s += '  rhomax: %s\n' % (self.rhomax, )
+        s += '  epsinf: %s\n' % (self.epsinf, )
+        return s
 
 
 class FG02SmoothStepCavity(SmoothStepCavity):
@@ -741,10 +826,11 @@ class FG02SmoothStepCavity(SmoothStepCavity):
             self.del_g_del_rho_g
         )
 
-    def print_parameters(self, text):
-        text('rho0: %s' % (self.rho0, ))
-        text('beta: %s' % (self.beta, ))
-        SmoothStepCavity.print_parameters(self, text)
+    def __str__(self):
+        s = SmoothStepCavity.__str__(self)
+        s += '  rho0: %s\n' % (self.rho0, )
+        s += '  beta: %s\n' % (self.beta, )
+        return s
 
 
 class SurfaceCalculator(NeedsGD):
@@ -768,8 +854,8 @@ class SurfaceCalculator(NeedsGD):
         NeedsGD.allocate(self)
         self.delta_A_delta_g_g = self.gd.empty()
 
-    def print_parameters(self, text):
-        pass
+    def __str__(self):
+        return 'Surface Calculator: %s\n' % (self.__class__, )
 
     def update(self, cavity):
         """Calculate A and delta_A_delta_g_g."""
@@ -789,7 +875,6 @@ class GradientSurface(SurfaceCalculator):
         SurfaceCalculator.__init__(self)
         self.nn = nn
         self.gradient = None
-        self.gradient_in = None
         self.gradient_out = None
         self.norm_grad_out = None
         self.div_tmp = None
@@ -797,7 +882,7 @@ class GradientSurface(SurfaceCalculator):
     def estimate_memory(self, mem):
         SurfaceCalculator.estimate_memory(self, mem)
         nbytes = self.gd.bytecount()
-        mem.subnode('Gradient', 5 * nbytes)
+        mem.subnode('Gradient', 4 * nbytes)
         mem.subnode('Divergence', nbytes)
 
     def allocate(self):
@@ -805,20 +890,15 @@ class GradientSurface(SurfaceCalculator):
         self.gradient = [
             Gradient(self.gd, i, 1.0, self.nn) for i in (0, 1, 2)
         ]
-        self.gradient_in = self.gd.empty()
         self.gradient_out = self.gd.empty(3)
         self.norm_grad_out = self.gd.empty()
         self.div_tmp = self.gd.empty()
 
     def update(self, cavity):
-        inner = cavity.get_inner_function()
         del_outer_del_inner = cavity.get_del_outer_del_inner()
         sign = np.sign(del_outer_del_inner.max() + del_outer_del_inner.min())
-        try:
-            self.gradient_out[...] = cavity.get_grad_inner()
-            self.norm_grad_out = (self.gradient_out ** 2).sum(0) ** .5
-        except NotImplementedError:
-            self.calc_grad(inner, cavity.get_inner_function_boundary_value())
+        self.gradient_out[...] = cavity.get_grad_inner()
+        self.norm_grad_out = (self.gradient_out ** 2).sum(0) ** .5
         self.A = sign * self.gd.integrate(
             del_outer_del_inner * self.norm_grad_out, global_integral=False
         )
@@ -833,18 +913,6 @@ class GradientSurface(SurfaceCalculator):
         if sign == 1:
             self.delta_A_delta_g_g *= -1.
 
-    def calc_grad(self, x, boundary):
-        if boundary != .0:
-            np.subtract(x, boundary, self.gradient_in)
-            gradient_in = self.gradient_in
-        else:
-            gradient_in = x
-        self.norm_grad_out.fill(.0)
-        for i in (0, 1, 2):
-            self.gradient[i].apply(gradient_in, self.gradient_out[i])
-            self.norm_grad_out += self.gradient_out[i] ** 2
-        self.norm_grad_out **= .5
-
     def calc_div(self, vec, out):
         self.gradient[0].apply(vec[0], out)
         self.gradient[1].apply(vec[1], self.div_tmp)
@@ -874,8 +942,8 @@ class VolumeCalculator(NeedsGD):
         NeedsGD.allocate(self)
         self.delta_V_delta_g_g = self.gd.empty()
 
-    def print_parameters(self, text):
-        pass
+    def __str__(self):
+        return "Volume Calculator: %s\n" % (self.__class__, )
 
     def update(self, cavity):
         """Calculate V and delta_V_delta_g_g"""
@@ -902,10 +970,11 @@ class KB51Volume(VolumeCalculator):
         self.compressibility = float(compressibility)
         self.temperature = float(temperature)
 
-    def print_parameters(self, text):
-        text('compressibility: %s' % (self.compressibility, ))
-        text('temperature:     %s' % (self.temperature, ))
-        VolumeCalculator.print_parameters(self, text)
+    def __str__(self):
+        s = VolumeCalculator.__str__(self)
+        s += '  compressibility: %s\n' % (self.compressibility, )
+        s += '  temperature:     %s\n' % (self.temperature, )
+        return s
 
     def allocate(self):
         VolumeCalculator.allocate(self)
