@@ -3,5 +3,5 @@ from myqueue.task import task
 
 def create_tasks():
     return [
-        task('molecules.py@1:1h'),
+        task('molecules.py', tmax='1h'),
         task('check.py', deps='molecules.py')]
