@@ -16,29 +16,30 @@ h = 0.15
 N_c = np.round(atoms.get_cell().diagonal() / h / 16) * 16
 
 m_c = GPAW(gpts=N_c, nbands=6, mixer=MixerDif(0.1, 5, weight=100.0),
-           #convergence={'bands':10},
+           # convergence={'bands':10},
            parallel={'domain': mpi.size},
            xc='PBE', txt='CO-m.txt', spinpol=True)
 
 m = atoms.copy()
-m.set_initial_magnetic_moments([-1,1])
+m.set_initial_magnetic_moments([-1, 1])
 m.calc = m_c
 m.get_potential_energy()
 
 d_c = GPAW(gpts=N_c, nbands=16, mixer=MixerDif(0.1, 5, weight=100.0),
-           convergence={'bands':10},
+           convergence={'bands': 10},
            parallel={'domain': mpi.size},
            xc='PBE', txt='CO-d.txt', spinpol=True)
 
 d = atoms.copy()
-d.set_initial_magnetic_moments([-1,1])
+d.set_initial_magnetic_moments([-1, 1])
 d_c.set(charge=1)
 d.calc = d_c
 d.get_potential_energy()
 
-istart=0 # band index of the first occ. band to consider
-jend=15  # band index of the last unocc. band to consider
-d_lr = LrTDDFT(d_c, xc='PBE', nspins=2 , istart=istart, jend=jend)
+istart = 0  # band index of the first occ. band to consider
+jend = 15   # band index of the last unocc. band to consider
+d_lr = LrTDDFT(d_c, xc='PBE', nspins=2,
+               restrict={'istart': istart, 'jend': jend})
 d_lr.diagonalize()
 
 pes = TDDFTPES(m_c, d_lr, d_c)
