@@ -1,15 +1,9 @@
-"""
-Test Placzek Raman implementation
-"""
-from ase import Atoms, Atom
-from ase.vibrations.placzek import Placzek, Profeta
-from ase.vibrations.albrecht import Albrecht
+from ase import Atom, Atoms
 
 from gpaw import GPAW
+from gpaw.analyse.overlap import Overlap
 from gpaw.lrtddft.kssingle import KSSingles
 from gpaw.test import equal
-from gpaw.analyse.overlap import Overlap
-
 
 txt = '-'
 txt = None
@@ -33,12 +27,16 @@ class GPAW_with_classmethod_read(GPAW):
 
 
 def test_lrtddft_placzek_profeta_albrecht(in_tmp_dir):
+    from ase.vibrations.albrecht import Albrecht
+    from ase.vibrations.placzek import Placzek, Profeta
+    from ase.vibrations.resonant_raman import ResonantRamanCalculator
+
     H2 = Atoms([Atom('H', (a / 2, a / 2, (c - R) / 2)),
                 Atom('H', (a / 2, a / 2, (c + R) / 2))],
                cell=(a, a, c))
 
-    gsname = exname = 'rraman'
-    exkwargs = {'eps': 0.0, 'jend': 3}
+    name = exname = 'rraman'
+    exkwargs = {'restrict': {'eps': 0.0, 'jend': 3}}
 
     if 1:
         calc = GPAW_with_classmethod_read(
@@ -51,68 +49,65 @@ def test_lrtddft_placzek_profeta_albrecht(in_tmp_dir):
         H2.calc = calc
         # H2.get_potential_energy()
 
-        pz = Placzek(H2, KSSingles, gsname=gsname, exname=exname,
-                     exkwargs=exkwargs,
-                     # XXX full does not work in parallel due to boxes
-                     # on different nodes
-                     # overlap=lambda x, y: Overlap(x).full(y)[0],
-                     overlap=lambda x, y: Overlap(x).pseudo(y)[0],
-                     txt=txt)
-        pz.run()
+        rr = ResonantRamanCalculator(
+            H2, KSSingles, name=name, exname=exname,
+            exkwargs=exkwargs,
+            # XXX full does not work in parallel due to boxes
+            # on different nodes
+            # overlap=lambda x, y: Overlap(x).full(y)[0],
+            overlap=lambda x, y: Overlap(x).pseudo(y)[0],
+            txt=txt)
+        rr.run()
 
     # check
 
     # Different Placzeck implementations should agree
 
     om = 5
-    pz = Placzek(H2, KSSingles, gsname=gsname, exname=exname, txt=txt)
-    pzi = pz.absolute_intensity(omega=om)[-1]
+    pz = Placzek(H2, KSSingles, name=name, exname=exname, txt=txt)
+    pzi = pz.get_absolute_intensities(omega=om)[-1]
 
-    pr = Profeta(H2, KSSingles, gsname=gsname, exname=exname,
+    pr = Profeta(H2, KSSingles, name=name, exname=exname,
                  approximation='Placzek', txt=txt)
-    pri = pr.absolute_intensity(omega=om)[-1]
+    pri = pr.get_absolute_intensities(omega=om)[-1]
     equal(pzi, pri, 0.1)
 
-    pr = Profeta(H2, KSSingles, gsname=gsname, exname=exname,
+    pr = Profeta(H2, KSSingles, name=name, exname=exname,
                  overlap=True,
                  approximation='Placzek', txt=txt)
-    pri = pr.absolute_intensity(omega=om)[-1]
+    pri = pr.get_absolute_intensities(omega=om)[-1]
     equal(pzi, pri, 0.1)
 
     """Albrecht and Placzek are approximately equal"""
 
-    al = Albrecht(H2, KSSingles, gsname=gsname, exname=exname,
+    al = Albrecht(H2, KSSingles, name=name, exname=exname,
                   overlap=True,
                   approximation='Albrecht', txt=txt)
-    ali = al.absolute_intensity(omega=om)[-1]
+    ali = al.get_absolute_intensities(omega=om)[-1]
     equal(pzi, ali, 1.5)
 
     """Albrecht A and P-P are approximately equal"""
 
-    pr = Profeta(H2, KSSingles, gsname=gsname, exname=exname,
+    pr = Profeta(H2, KSSingles, name=name, exname=exname,
                  overlap=True,
                  approximation='P-P', txt=txt)
-    pri = pr.absolute_intensity(omega=om)[-1]
+    pri = pr.get_absolute_intensities(omega=om)[-1]
 
-    al = Albrecht(H2, KSSingles, gsname=gsname, exname=exname,
+    al = Albrecht(H2, KSSingles, name=name, exname=exname,
                   overlap=True,
                   approximation='Albrecht A', txt=txt)
-    ali = al.absolute_intensity(omega=om)[-1]
+    ali = al.get_absolute_intensities(omega=om)[-1]
     equal(pri, ali, 3)
 
     """Albrecht B+C and Profeta are approximately equal"""
 
-    pr = Profeta(H2, KSSingles, gsname=gsname, exname=exname,
+    pr = Profeta(H2, KSSingles, name=name, exname=exname,
                  overlap=True,
                  approximation='Profeta', txt=txt)
-    pri = pr.absolute_intensity(omega=om)[-1]
+    pri = pr.get_absolute_intensities(omega=om)[-1]
 
-    al = Albrecht(H2, KSSingles, gsname=gsname, exname=exname,
+    al = Albrecht(H2, KSSingles, name=name, exname=exname,
                   overlap=True,
                   approximation='Albrecht BC', txt=txt)
-    ali = al.absolute_intensity(omega=om)[-1]
+    ali = al.get_absolute_intensities(omega=om)[-1]
     equal(pri, ali, 3)
-
-
-if __name__ == '__main__':
-    test_lrtddft_placzek_profeta_albrecht(True)
