@@ -14,27 +14,30 @@ def test_solvation_lrtddft():
     atoms = Cluster(molecule('H2'))
     atoms.minimal_box(vac, h)
 
-    # convenient way to use HW14 water parameters:
     calc = solv.SolvationGPAW(
         xc='PBE', h=0.2,  # non-solvent DFT parameters
         nbands=3,
         convergence={'energy': 0.1, 'eigenstates': 0.01, 'density': 0.1},
+        # convenient way to use HW14 water parameters:
         **solv.get_HW14_water_kwargs())
 
+    # do the ground state calculation
     atoms.calc = calc
     atoms.get_potential_energy()
     print(id(calc.hamiltonian.poisson.dielectric))
     print(id(calc.hamiltonian.dielectric))
 
+    # linear response using ground state Poisson
+    lrw = LrTDDFT(calc)
+    lrw.diagonalize()
 
-    # We test the agreement of a pure RPA kernel with setting eps to 1
-    lr = LrTDDFT(calc, poisson=PoissonSolver('fd', nn=calc.hamiltonian.poisson.nn))
+    # We test the agreement of a pure RPA kernel
+    # with setting eps to 1
+    
+    lr = LrTDDFT(calc,
+                 poisson=PoissonSolver('fd', nn=calc.hamiltonian.poisson.nn))
     lr.diagonalize()
 
-    if 0:
-        lreps = LrTDDFT(calc)
-        lreps.diagonalize()
-
     calc.hamiltonian.poisson.dielectric.epsinf = 1.
     lr1 = LrTDDFT(calc)
     lr1.diagonalize()
