@@ -10,7 +10,9 @@ from gpaw.symmetry import atoms2symmetry
 def test_symmetry_check():
     a = 3.9
     atoms = Atoms('Ge2Si4',
-                  cell=[[a, 0, 0], [0, a, 0], [-a / 2, -a / 2, a * 3 / 2**0.5]],
+                  cell=[[a, 0, 0],
+                        [0, a, 0],
+                        [-a / 2, -a / 2, a * 3 / 2**0.5]],
                   scaled_positions=[[2 / 3, 2 / 3, 1 / 3],
                                     [11 / 12, 5 / 12, 5 / 6],
                                     [0, 0, 0],
