@@ -11,12 +11,10 @@ def test_xc_nonselfconsistentLDA(in_tmp_dir):
     calc = GPAW(gpts=(n, n, n), nbands=1, xc='LDA')
     atoms.calc = calc
     e1 = atoms.get_potential_energy()
-    niter1 = calc.get_number_of_iterations()
     e1ref = calc.get_reference_energy()
     de12 = calc.get_xc_difference({'name': 'PBE', 'stencil': 1})
     calc.set(xc={'name': 'PBE', 'stencil': 1})
     e2 = atoms.get_potential_energy()
-    niter2 = calc.get_number_of_iterations()
     e2ref = calc.get_reference_energy()
     de21 = calc.get_xc_difference('LDA')
     print(e1ref + e1 + de12, e2ref + e2)
@@ -32,6 +30,5 @@ def test_xc_nonselfconsistentLDA(in_tmp_dir):
     equal(de21, de21b, 9e-8)
 
     energy_tolerance = 0.0007
-    niter_tolerance = 0
-    equal(e1, -0.0961003634812, energy_tolerance) # svnversion 5252
-    equal(e2, -0.0790249564625, energy_tolerance) # svnversion 5252
+    equal(e1, -0.0961003634812, energy_tolerance)  # svnversion 5252
+    equal(e2, -0.0790249564625, energy_tolerance)  # svnversion 5252
