@@ -1,15 +1,21 @@
 from math import pi, sqrt
+from warnings import warn
+from typing import Optional, List, Dict
 
 import numpy as np
 from ase.units import Bohr, Ha
 
+from gpaw import GPAW
 from gpaw.atom.shapefunc import shape_functions
 from gpaw.fftw import get_efficient_fft_size
 from gpaw.grid_descriptor import GridDescriptor
-from gpaw.lfc import LFC
+from gpaw.lfc import LocalizedFunctionsCollection as LFC
 from gpaw.utilities import h2gpts
 from gpaw.wavefunctions.pw import PWDescriptor
 from gpaw.mpi import serial_comm
+from gpaw.setup import Setup
+from gpaw.spline import Spline
+from gpaw.hints import Array3D
 
 
 class Interpolator:
@@ -30,33 +36,46 @@ class PS2AE:
     Interpolates PS wave functions to a fine grid and adds PAW
     corrections in order to obtain true AE wave functions.
     """
-    def __init__(self, calc, h=0.05, n=2):
+    def __init__(self,
+                 calc: GPAW,
+                 grid_spacing: float = 0.05,
+                 n: int = 2,
+                 h=None  # deprecated
+                 ):
         """Create transformation object.
 
         calc: GPAW calculator object
             The calcalator that has the wave functions.
-        h: float
+        grid_spacing: float
             Desired grid-spacing in Angstrom.
         n: int
             Force number of points to be a mulitiple of n.
         """
+        if h is not None:
+            warn('Please use grid_spacing=... instead of h=...')
+            grid_spacing = h
+
         self.calc = calc
         gd = calc.wfs.gd
 
         gd1 = GridDescriptor(gd.N_c, gd.cell_cv, comm=serial_comm)
 
         # Descriptor for the final grid:
-        N_c = h2gpts(h / Bohr, gd.cell_cv)
+        N_c = h2gpts(grid_spacing / Bohr, gd.cell_cv)
         N_c = np.array([get_efficient_fft_size(N, n) for N in N_c])
         gd2 = self.gd = GridDescriptor(N_c, gd.cell_cv, comm=serial_comm)
         self.interpolator = Interpolator(gd1, gd2, self.calc.wfs.dtype)
 
-        self.dphi = None  # PAW correction (will be initialized when needed)
+        self._dphi: Optional[LFC] = None  # PAW correction
 
-    def _initialize_corrections(self):
-        if self.dphi is not None:
-            return
-        splines = {}
+        self.dv = self.gd.dv * Bohr**3
+
+    @property
+    def dphi(self) -> LFC:
+        if self._dphi is not None:
+            return self._dphi
+
+        splines: Dict[Setup, List[Spline]] = {}
         dphi_aj = []
         for setup in self.calc.wfs.setups:
             dphi_j = splines.get(setup)
@@ -70,13 +89,20 @@ class PS2AE:
                     dphi_g = (phi_g - phit_g)[:gcut]
                     dphi_j.append(setup.rgd.spline(dphi_g, rcut, l,
                                                    points=200))
+                splines[setup] = dphi_j
             dphi_aj.append(dphi_j)
 
-        self.dphi = LFC(self.gd, dphi_aj, kd=self.calc.wfs.kd.copy(),
-                        dtype=self.calc.wfs.dtype)
-        self.dphi.set_positions(self.calc.spos_ac)
+        self._dphi = LFC(self.gd, dphi_aj, kd=self.calc.wfs.kd.copy(),
+                         dtype=self.calc.wfs.dtype)
+        self._dphi.set_positions(self.calc.spos_ac)
 
-    def get_wave_function(self, n, k=0, s=0, ae=True):
+        return self._dphi
+
+    def get_wave_function(self,
+                          n: int,
+                          k: int = 0,
+                          s: int = 0,
+                          ae: bool = True) -> Array3D:
         """Interpolate wave function.
 
         n: int
@@ -92,7 +118,7 @@ class PS2AE:
                                                    pad=True, periodic=True)
         psi_R = self.interpolator.interpolate(psi_r * Bohr**1.5)
         if ae:
-            self._initialize_corrections()
+            dphi = self.dphi
             wfs = self.calc.wfs
             P_nI = wfs.collect_projections(k, s)
             if wfs.world.rank == 0:
@@ -102,11 +128,36 @@ class PS2AE:
                     I2 = I1 + setup.ni
                     P_ai[a] = P_nI[n, I1:I2]
                     I1 = I2
-                self.dphi.add(psi_R, P_ai, k)
+                dphi.add(psi_R, P_ai, k)
             wfs.world.broadcast(psi_R, 0)
         return psi_R * Bohr**-1.5
 
-    def get_electrostatic_potential(self, ae=True, rcgauss=0.02):
+    def get_pseudo_density(self,
+                           add_compensation_charges: bool = True) -> Array3D:
+        """Interpolate pseudo density."""
+        dens = self.calc.density
+        gd1 = dens.gd
+        assert gd1.comm.size == 1
+        interpolator = Interpolator(gd1, self.gd)
+        dens_r = dens.nt_sG[:dens.nspins].sum(axis=0)
+        dens_R = interpolator.interpolate(dens_r)
+
+        if add_compensation_charges:
+            dens.calculate_multipole_moments()
+            ghat = LFC(self.gd, [setup.ghat_l for setup in dens.setups],
+                       integral=sqrt(4 * pi))
+            ghat.set_positions(self.calc.spos_ac)
+            Q_aL = {}
+            for a, Q_L in dens.Q_aL.items():
+                Q_aL[a] = Q_L.copy()
+                Q_aL[a][0] += dens.setups[a].Nv / (4 * pi)**0.5
+            ghat.add(dens_R, Q_aL)
+
+        return dens_R / Bohr**3
+
+    def get_electrostatic_potential(self,
+                                    ae: bool = True,
+                                    rcgauss: float = 0.02) -> Array3D:
         """Interpolate electrostatic potential.
 
         Return value in eV.
@@ -128,7 +179,9 @@ class PS2AE:
 
         return v_R * Ha
 
-    def add_potential_correction(self, v_R, rcgauss: float) -> None:
+    def add_potential_correction(self,
+                                 v_R: Array3D,
+                                 rcgauss: float) -> None:
         dens = self.calc.density
         dens.D_asp.redistribute(dens.atom_partition.as_serial())
         dens.Q_aL.redistribute(dens.atom_partition.as_serial())
