@@ -354,6 +354,7 @@ class PWDescriptor:
             Q_G = self.Q_qG[q]
             assert len(c_G) == len(Q_G)
             _gpaw.pw_insert(c_G, Q_G, scale, self.tmp_Q)
+
             if self.dtype == float:
                 t = self.tmp_Q[:, :, 0]
                 n, m = self.gd.N_c[:2] // 2 - 1
@@ -398,7 +399,7 @@ class PWDescriptor:
         """Gather coefficients from a_rG[r] on rank r.
 
         On rank r, an array of all G-vector coefficients will be returned.
-        These will be gathers from a_rG[r] on all the cores.
+        These will be gathered from a_rG[r] on all the cores.
         """
         comm = self.gd.comm
         if comm.size == 1:
@@ -942,7 +943,8 @@ class PWWaveFunctions(FDPWWaveFunctions):
 
     def get_wave_function_array(self, n, k, s, realspace=True,
                                 cut=True, periodic=False):
-        kpt_rank, u = self.kd.get_rank_and_index(s, k)
+        kpt_rank, q = self.kd.get_rank_and_index(k)
+        u = q * self.nspins + s
         band_rank, myn = self.bd.who_has(n)
 
         rank = self.world.rank
@@ -954,7 +956,7 @@ class PWWaveFunctions(FDPWWaveFunctions):
                 psit_G = self.gd.collect(psit_G)
             else:
                 assert not cut
-                tmp_G = self.pd.gather(psit_G, self.mykpts[u].q)
+                tmp_G = self.pd.gather(psit_G, self.kpt_u[u].q)
                 if tmp_G is not None:
                     ng = self.pd.ngmax
                     if self.collinear:
@@ -1022,11 +1024,8 @@ class PWWaveFunctions(FDPWWaveFunctions):
         Q_G = np.empty(self.pd.ngmax, np.int32)
         kk = 0
         for r in range(self.kd.comm.size):
-            for q, ks in enumerate(self.kd.get_indices(r)):
-                s, k = divmod(ks, self.kd.nibzkpts)
+            for q, k in enumerate(self.kd.get_indices(r)):
                 ng = self.ng_k[k]
-                if s == 1:
-                    return
                 if r == self.kd.comm.rank:
                     Q_G[:ng] = self.pd.Q_qG[q]
                     if r > 0:
@@ -1056,7 +1055,7 @@ class PWWaveFunctions(FDPWWaveFunctions):
         c = reader.bohr**1.5
         if reader.version < 0:
             c = 1  # old gpw file
-        for kpt in self.mykpts:
+        for kpt in self.kpt_u:
             ng = self.ng_k[kpt.k]
             index = (kpt.s, kpt.k) if self.collinear else (kpt.k,)
             psit_nG = reader.wave_functions.proxy('coefficients', *index)
@@ -1119,7 +1118,7 @@ class PWWaveFunctions(FDPWWaveFunctions):
         return H_GG, S_GG
 
     @timer('Full diag')
-    def diagonalize_full_hamiltonian(self, ham, atoms, occupations, log,
+    def diagonalize_full_hamiltonian(self, ham, atoms, log,
                                      nbands=None, ecut=None, scalapack=None,
                                      expert=False):
 
@@ -1151,6 +1150,7 @@ class PWWaveFunctions(FDPWWaveFunctions):
             iu = None
 
         self.bd = bd = BandDescriptor(nbands, self.bd.comm)
+        self.occupations.bd = bd
 
         log('Diagonalizing full Hamiltonian ({} lowest bands)'.format(nbands))
         log('Matrix size (min, max): {}, {}'.format(self.pd.ngmin,
@@ -1167,6 +1167,7 @@ class PWWaveFunctions(FDPWWaveFunctions):
         if S > 1:
             if isinstance(scalapack, (list, tuple)):
                 nprow, npcol, b = scalapack
+                assert nprow * npcol == S, (nprow, npcol, S)
             else:
                 nprow = int(round(S**0.5))
                 while S % nprow != 0:
@@ -1179,11 +1180,10 @@ class PWWaveFunctions(FDPWWaveFunctions):
             bg2 = BlacsGrid(bd.comm, nprow, npcol)
             scalapack = True
         else:
-            nprow = npcol = 1
             scalapack = False
 
         self.set_positions(atoms.get_scaled_positions())
-        self.mykpts[0].P = None
+        self.kpt_u[0].projections = None
         self.allocate_arrays_for_projections(self.pt.my_atom_indices)
 
         myslice = bd.get_slice()
@@ -1241,14 +1241,14 @@ class PWWaveFunctions(FDPWWaveFunctions):
 
         pb.finish()
 
-        occupations.calculate(self)
+        self.calculate_occupation_numbers()
 
         return nbands
 
     def initialize_from_lcao_coefficients(self, basis_functions):
         psit_nR = self.gd.empty(1, self.dtype)
 
-        for kpt in self.mykpts:
+        for kpt in self.kpt_u:
             if self.kd.gamma:
                 emikr_R = 1.0
             else:
@@ -1416,8 +1416,7 @@ class PWLFC(BaseLFC):
                 self.s_J[J] = s
                 J += 1
 
-        # self.lmax = max(self.l_s, default=-1)  # needs Python 3.4
-        self.lmax = max(self.l_s) if len(self.l_s) > 0 else -1
+        self.lmax = max(self.l_s, default=-1)
 
         # Spherical harmonics:
         for q, K_v in enumerate(self.pd.K_qv):
@@ -1624,14 +1623,17 @@ class PWLFC(BaseLFC):
         P_ani = {a: P_in.T for a, P_in in out.items()}
         self.integrate(psit.array, P_ani, psit.kpt)
 
-    def derivative(self, a_xG, c_axiv, q=-1):
+    def derivative(self, a_xG, c_axiv=None, q=-1):
         c_vxI = np.zeros((3,) + a_xG.shape[:-1] + (self.nI,), self.pd.dtype)
-        b_vxI = c_vxI.reshape((3, np.prod(c_vxI.shape[1:-1], dtype=int),
-                               self.nI))
-        a_xG = a_xG.reshape((-1, a_xG.shape[-1])).view(self.pd.dtype)
+        nx = np.prod(c_vxI.shape[1:-1], dtype=int)
+        b_vxI = c_vxI.reshape((3, nx, self.nI))
+        a_xG = a_xG.reshape((nx, a_xG.shape[-1])).view(self.pd.dtype)
 
         alpha = 1.0 / self.pd.gd.N_c.prod()
 
+        if c_axiv is None:
+            c_axiv = self.dict(a_xG.shape[:-1], derivative=True)
+
         K_v = self.pd.K_qv[q]
 
         x = 0.0
@@ -1666,6 +1668,8 @@ class PWLFC(BaseLFC):
                     c_axiv[a][..., v] = (1.0j * self.eikR_qa[q][a] *
                                          c_vxI[v, ..., I1:I2])
 
+        return c_axiv
+
     def stress_tensor_contribution(self, a_xG, c_axi=1.0, q=-1):
         cache = {}
         things = []
