@@ -187,14 +187,14 @@ class SIC(XCFunctional):
             'finegrid': self.finegrid,
             'parameters': dict(self.parameters)}
 
-    def initialize(self, density, hamiltonian, wfs, occ=None):
+    def initialize(self, density, hamiltonian, wfs):
         assert wfs.kd.gamma
         assert not wfs.gd.pbc_c.any()
         assert wfs.bd.comm.size == 1  # band parallelization unsupported
 
         self.wfs = wfs
         self.dtype = float
-        self.xc.initialize(density, hamiltonian, wfs, occ)
+        self.xc.initialize(density, hamiltonian, wfs)
         self.kpt_comm = wfs.kd.comm
         self.nspins = wfs.nspins
         self.nbands = wfs.bd.nbands
